==> jc-1.4.0.tar.gz: javax/print/attribute/AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet.h <==
// class javax.print.attribute.AttributeSetUtilities$UnmodifiablePrintJobAttributeSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 331ae21ae563dec4 javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet
// @dep_class 92894d211f2497aa javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet

#include "javax/print/attribute/AttributeSetUtilities__24UnmodifiableAttributeSet.h"

#ifndef _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet_H_
#define _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_attribute_PrintJobAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$sub_refs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$sub_nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$refs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$object	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$object;

typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vmethods	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vtable	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vtype	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vtype;

// Constructors
extern void _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$method$_init$e5a7e9c8f2357d04(_jc_env *, struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$object *, struct _jc_object *);

// Virtual methods structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$refs {
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$object {
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vtype _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet.h <==
// class javax.print.attribute.AttributeSetUtilities$UnmodifiablePrintJobAttributeSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 331ae21ae563dec4 javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet
// @dep_class 92894d211f2497aa javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet

#include "javax/print/attribute/AttributeSetUtilities__24UnmodifiableAttributeSet.h"

#ifndef _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet_H_
#define _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_attribute_PrintJobAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$sub_refs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$sub_nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$refs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$object	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$object;

typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vmethods	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vtable	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vtype	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vtype;

// Constructors
extern void _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$method$_init$e5a7e9c8f2357d04(_jc_env *, struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$refs {
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$object {
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$vtype _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintJobAttributeSet_H_ */
